@@ -12,6 +12,7 @@
 #include <QVBoxLayout>
 #include <QScrollArea>
 #include <QWidget>
+#include <QFile>
 
 
 #ifdef Q_WS_HILDON
@@ -77,6 +78,8 @@ void MainWindow::SetupThisUi()
     int bgcoloralpha = oSettings->value("bgcoloralpha", int(180)).toInt();   
     int fontSizeIndex = oSettings->value("fontsize", int(3)).toInt();
     QString fontFamilyName = oSettings->value("fontfamily", "Nokia Sans SemiBold").toString();
+    QString language = oSettings->value("language", "System").toString();
+
 
 
 
@@ -213,3 +216,4 @@ void MainWindow::changeEvent(QEvent *e)
 }
 
 
+
