@@ -13,7 +13,7 @@ settingsdlg::settingsdlg(QWidget *parent) :
     ui(new Ui::settingsdlg)
 {
     ui->setupUi(this);
-    this->setWindowTitle("Edit settings");
+    this->setWindowTitle(tr("Edit settings"));
 
 
     QScrollArea *sa = new QScrollArea( this );
